@@ -10,6 +10,8 @@
 
 """ Defines the PlotAxis class, and associated validator and UI.
 """
+import logging
+
 # Major library import
 from numpy import (
     array,
@@ -58,6 +60,8 @@ from .abstract_overlay import AbstractOverlay
 from .label import Label
 from .log_mapper import LogMapper
 
+logger = logging.getLogger(__name__)
+
 
 def DEFAULT_TICK_FORMATTER(val):
     return ("%f" % val).rstrip("0").rstrip(".")
@@ -83,7 +87,7 @@ class PlotAxis(AbstractOverlay):
     title = Str()  # May want to add PlotLabel option
 
     #: The font of the title.
-    title_font = KivaFont("modern 12")
+    title_font = KivaFont("sans-serif 12")
 
     #: The spacing between the axis line and the title
     title_spacing = Union(Constant("auto"), Float)
@@ -101,7 +105,7 @@ class PlotAxis(AbstractOverlay):
     tick_color = ColorTrait("black")
 
     #: The font of the tick labels.
-    tick_label_font = KivaFont("modern 10")
+    tick_label_font = KivaFont("sans-serif 10")
 
     #: The color of the tick labels.
     tick_label_color = ColorTrait("black")
@@ -500,20 +504,21 @@ class PlotAxis(AbstractOverlay):
             screenlow, screenhigh = screenhigh, screenlow
 
         if (
-            (datalow == datahigh)
+            (datalow >= datahigh)
             or (screenlow == screenhigh)
             or (datalow in [inf, -inf])
             or (datahigh in [inf, -inf])
         ):
+            if datalow > datahigh:
+                logger.warning(
+                    "{self.mapper} has an invalid data range with "
+                    "low={datalow} > high={datahigh}; unable to compute axis "
+                    "ticks."
+                )
             self._reset_cache()
             self._cache_valid = True
             return
 
-        if datalow > datahigh:
-            raise RuntimeError(
-                "DataRange low is greater than high; unable to compute axis ticks."
-            )
-
         if not self.tick_generator:
             return
 
