@@ -130,7 +130,7 @@ class PolarLineRenderer(AbstractPlotRenderer):
     def _downsample(self):
         return self.map_screen(self._cached_data_pts)
 
-    def _draw_plot(self, *args, **kw):
+    def _draw_plot(self, gc, *args, **kw):
         """Draws the 'plot' layer."""
         self._gather_points()
         self._render(gc, self._cached_data_pts)
