@@ -9,10 +9,9 @@
 # Thanks for using Enthought open source!
 
 import os
-
+import platform
 import tempfile
 from contextlib import contextmanager
-
 import unittest
 
 import numpy as np
@@ -37,7 +36,7 @@ from chaco.api import (
 # The Quartz backend rescales pixel values, so use a higher threshold.
 MAX_RMS_ERROR = 16 if ETSConfig.kiva_backend == "quartz" else 1
 
-IMAGE = np.random.random_integers(0, 255, size=(100, 200)).astype(np.uint8)
+IMAGE = np.random.randint(0, 256, size=(100, 200)).astype(np.uint8)
 RGB = np.dstack([IMAGE] * 3)
 # Rendering adds rows and columns for some reason.
 TRIM_RENDERED = (slice(1, -1), slice(1, -1), 0)
@@ -207,6 +206,9 @@ class TestResultImage(unittest.TestCase):
 
     # regression test for enthought/chaco#528
     @unittest.skipIf(is_null, "Skip on 'null' toolkit")
+    @unittest.skipIf(
+        ETSConfig.toolkit == "wx" and platform.system() == 'Darwin',
+        "Test does not work correctly on wx; https://github.com/enthought/chaco/issues/919")
     def test_resize_to_zero(self):
         class TestResize(HasTraits):
             plot = Instance(Component)
