@@ -9,9 +9,10 @@
 # Thanks for using Enthought open source!
 
 import unittest
+import platform
 
 import numpy as np
-from numpy import alltrue, arange, array
+from numpy import arange, array
 
 from enable.api import ComponentEditor
 from enable.testing import EnableTestAssistant
@@ -26,6 +27,7 @@ from chaco.tools.api import PanTool, ZoomTool
 
 
 class PlotTestCase(unittest.TestCase):
+
     def test_plot_from_unsupported_array_shape(self):
         arr = arange(8).reshape(2, 2, 2)
         data = ArrayPlotData(x=arr, y=arr)
@@ -63,7 +65,7 @@ class PlotTestCase(unittest.TestCase):
         gc = PlotGraphicsContext((250, 250))
         gc.render_component(plot)
         actual = gc.bmp_array[:, :, :]
-        self.assertFalse(alltrue(actual == 255))
+        self.assertFalse(np.all(actual == 255))
 
     def test_segment_plot_color(self):
         x = arange(10)
@@ -77,7 +79,7 @@ class PlotTestCase(unittest.TestCase):
         gc = PlotGraphicsContext((250, 250))
         gc.render_component(plot)
         actual = gc.bmp_array[:, :, :]
-        self.assertFalse(alltrue(actual == 255))
+        self.assertFalse(np.all(actual == 255))
 
     def test_segment_plot_color_width(self):
         x = arange(10)
@@ -94,7 +96,7 @@ class PlotTestCase(unittest.TestCase):
         gc = PlotGraphicsContext((250, 250))
         gc.render_component(plot)
         actual = gc.bmp_array[:, :, :]
-        self.assertFalse(alltrue(actual == 255))
+        self.assertFalse(np.all(actual == 255))
 
     def test_segment_plot_map_screen(self):
         x = arange(10)
@@ -120,7 +122,7 @@ class PlotTestCase(unittest.TestCase):
         gc = PlotGraphicsContext((250, 250))
         gc.render_component(plot)
         actual = gc.bmp_array[:, :, :]
-        self.assertFalse(alltrue(actual == 255))
+        self.assertFalse(np.all(actual == 255))
 
     def check_map_screen(self, renderer):
         arr = arange(10)
@@ -170,6 +172,10 @@ class EmptyLinePlot(HasTraits):
 @unittest.skipIf(ETSConfig.toolkit == "null", "Skip on 'null' toolkit")
 class TestEmptyPlot(unittest.TestCase, EnableTestAssistant):
 
+
+    @unittest.skipIf(
+        ETSConfig.toolkit == "wx" and platform.system() == 'Darwin',
+        "Test does not work correctly on wx; https://github.com/enthought/chaco/issues/919")
     def test_dont_crash_on_click(self):
         from traitsui.testing.api import UITester
         tester = UITester()
