@@ -6,7 +6,7 @@ Based on updating_plot.py
 # Major library imports
 import pyaudio
 from numpy import zeros, linspace, short, fromstring, transpose, array, empty
-from scipy import fft
+from scipy.fft import fft
 
 # Enthought library imports
 from enable.api import Window, Component, ComponentEditor
@@ -100,7 +100,7 @@ class WaterfallRenderer(LinePlot):
 
 def _create_plot_component(obj):
     # Setup the spectrum plot
-    frequencies = linspace(0.0, float(SAMPLING_RATE) / 2, num=NUM_SAMPLES / 2)
+    frequencies = linspace(0.0, float(SAMPLING_RATE) / 2, num=NUM_SAMPLES // 2)
     obj.spectrum_data = ArrayPlotData(frequency=frequencies)
     empty_amplitude = zeros(NUM_SAMPLES // 2)
     obj.spectrum_data.set_data("amplitude", empty_amplitude)
